'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Button;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Link = require('./Link');

var _Link2 = _interopRequireDefault(_Link);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Button(_ref) {
  var active = _ref.active,
      children = _ref.children,
      disabled = _ref.disabled,
      enforceA = _ref.enforceA,
      onClick = _ref.onClick,
      onMouseDown = _ref.onMouseDown,
      openNewTab = _ref.openNewTab,
      replace = _ref.replace,
      size = _ref.size,
      theme = _ref.theme,
      to = _ref.to;

  var className = theme.button;
  if (theme[size]) className += ' ' + theme[size];
  if (active && theme.active) className += ' ' + theme.active;
  if (disabled) {
    if (theme.disabled) className += ' ' + theme.disabled;
    return _react2.default.createElement(
      'div',
      { className: className },
      children
    );
  } else if (to) {
    if (theme.link) className += ' ' + theme.link;
    return _react2.default.createElement(
      _Link2.default,
      {
        className: className,
        enforceA: enforceA,
        onClick: onClick,
        onMouseDown: onMouseDown,
        openNewTab: openNewTab,
        replace: replace,
        to: to
      },
      children
    );
  }
  if (theme.regular) className += ' ' + theme.regular;
  return _react2.default.createElement(
    'button',
    {
      className: className,
      onClick: onClick,
      onMouseDown: onMouseDown
    },
    children
  );
} /**
   * The Button component provide a standard button / button-like link:
   * - When disabled, it renders as <div>;
   * - When no "to" prop is passed in, it renders as <button>;
   * - Otherwise, it renders as <Link>.
   */

Button.defaultProps = {
  active: false,
  children: null,
  disabled: false,
  enforceA: false,
  onClick: null,
  onMouseDown: null,
  openNewTab: false,
  replace: false,
  size: null,
  to: null
};

Button.propTypes = {
  active: _propTypes2.default.bool,
  children: _propTypes2.default.node,
  disabled: _propTypes2.default.bool,
  enforceA: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  onMouseDown: _propTypes2.default.func,
  openNewTab: _propTypes2.default.bool,
  replace: _propTypes2.default.bool,
  size: _propTypes2.default.string,
  theme: _propTypes2.default.shape({
    button: _propTypes2.default.string.isRequired,
    disabled: _propTypes2.default.string.isRequired,
    link: _propTypes2.default.string,
    regular: _propTypes2.default.string
  }).isRequired,
  to: _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.string])
};