'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports.default = GenericLink;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _urlParse = require('url-parse');

var _urlParse2 = _interopRequireDefault(_urlParse);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The GenericLink wraps around React Router's Link or NavLink component, to
 * automatically replace them by regular <a> elements when:
 * - The target reference points to another domain;
 * - User opts to open the reference in a new tab;
 * - User explicitely opts to use <a>.
 */

/* global document, window */

function GenericLink(props) {
  var children = props.children,
      className = props.className,
      enforceA = props.enforceA,
      _onClick = props.onClick,
      onMouseDown = props.onMouseDown,
      openNewTab = props.openNewTab,
      routerLinkType = props.routerLinkType,
      to = props.to;
  /* Renders the link as <a> element if either opted explicitely, or the link
   * should open a new tab, or it is an anchor reference. */

  if (enforceA || openNewTab || to.startsWith('#')) {
    return _react2.default.createElement(
      'a',
      {
        className: className,
        href: to,
        onClick: _onClick,
        onMouseDown: onMouseDown,
        rel: openNewTab ? 'noopener noreferrer' : '',
        target: openNewTab ? '_blank' : ''
      },
      children
    );
  }

  var linkProps = _lodash2.default.omit(props, ['children', 'enforceA', 'openNewTab', 'routerLinkType']);

  /* Otherwise we render the link as React Router's Link or NavLink element. */
  return _react2.default.createElement(routerLinkType, (0, _extends3.default)({}, linkProps, {
    onClick: function onClick(e) {
      /* If a custom onClick(..) handler was provided we execute it. */
      if (_onClick) _onClick(e);

      /* If the URL leads to a different domain we make transition using JS,
       * preventing event processing by React Router. */
      var url = new _urlParse2.default(to);
      if (url.origin !== document.location.origin) {
        document.location = to;
        e.preventDefault();

        /* Scroll to the top-left corner of the page, just in case the link
         * references the same page we are already in. */
      } else window.scroll(0, 0);
    }
  }), children);
}

GenericLink.defaultProps = {
  children: null,
  className: null,
  enforceA: false,
  onClick: null,
  onMouseDown: null,
  openNewTab: false,
  replace: false,
  to: ''
};

GenericLink.propTypes = {
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  enforceA: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  onMouseDown: _propTypes2.default.func,
  openNewTab: _propTypes2.default.bool,
  routerLinkType: _propTypes2.default.func.isRequired,
  to: _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.string])
};